# How to contribute

## Have you found a bug?
If so, [open an issue](https://github.com/guillermo-carrasco/twistream/issues/new) explaining the issue.

Please try to add as much information about the issue as possible, such as Python version and stack trace.

## Want to add a feature? You're most welcome!
That's awesome and contributions are very much appreciated :-D!

Just [create a pull request](https://github.com/guillermo-carrasco/twistream/pull/new) with your changes :)

Thanks!
